



.. image:: https://img.shields.io/pypi/v/EngCoolProp.svg
        
.. image:: https://img.shields.io/badge/python-3.7|3.8|3.9|3.10|3.11|3.12-blue

.. image:: https://img.shields.io/pypi/l/EngCoolProp.svg

